# Relation Mapping Between ServiceNow and SAP LeanIX
### On this page
  * [Selecting an SAP LeanIX Relation](https://help.sap.com/docs/leanix/ea/relation-mapping-between-servicenow-and-sap-leanix#selecting-an-sap-leanix-relation)
  * [Configuring a ServiceNow Relation](https://help.sap.com/docs/leanix/ea/relation-mapping-between-servicenow-and-sap-leanix#configuring-a-servicenow-relation)
  * [CMDB_REL_CI](https://help.sap.com/docs/leanix/ea/relation-mapping-between-servicenow-and-sap-leanix#cmdb_rel_ci)
  * [REFERENCE_FIELD](https://help.sap.com/docs/leanix/ea/relation-mapping-between-servicenow-and-sap-leanix#reference_field)
  * [MAPPING_TABLE](https://help.sap.com/docs/leanix/ea/relation-mapping-between-servicenow-and-sap-leanix#mapping_table)
  * [GRAPH_RULE_CONSTRAINT](https://help.sap.com/docs/leanix/ea/relation-mapping-between-servicenow-and-sap-leanix#graph_rule_constraint)
  * [Relation Sync Behavior](https://help.sap.com/docs/leanix/ea/relation-mapping-between-servicenow-and-sap-leanix#relation-sync-behavior)


Map relations between records in ServiceNow and fact sheets in SAP LeanIX.
After configuring how you want to map fact sheets to ServiceNow tables—or vice versa—you can also map relations between those fact sheets or records to the other system.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27413d9c7a441014a0f7d05ed06eb00b_LowRes.png)
On the ServiceNow configuration page, under Relation Mapping, find the mapping you need or create a new one. Configure the following:
  * Active: Activate or deactivate a relation mapping.
  * Fact Sheet Mapping: Choose entities between which you want to configure relation mapping.
  * Source System: Select the source system for relations.
  * Configuration: Configure details for the relation.
